﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;

namespace PhoneAppBounce
{
    public partial class MainPage : PhoneApplicationPage
    {
        // Random number generator
        private Random random = new Random();

        // Current color RGB values
        private double r = 255;
        private double g = 255;
        private double b = 255;


        // Constructor
        public MainPage()
        {
            InitializeComponent();

            // Register for touch events
            Touch.FrameReported += new TouchFrameEventHandler(Touch_FrameReported);

            // Disable the frame rate counter (tiny numbers on the right side of the screen)
            Application.Current.Host.Settings.EnableFrameRateCounter = false;
        }


        void Touch_FrameReported(object sender, TouchFrameEventArgs e)
        {
            // Get all current touch points
            TouchPointCollection tpc = e.GetTouchPoints(this.canvas);

            // For each current touch point, do...
            foreach (TouchPoint tp in tpc)
            {
                // Pick a random size for the ball
                double drawingSize = this.random.Next(60) + 30;

                // ...create a new ellipse, assign a random color, and set the default drawing size
                Ellipse ellipse = new Ellipse();
                ellipse.Fill = new SolidColorBrush(this.GetRandomFadingColour());
                ellipse.Height = drawingSize;
                ellipse.Width = drawingSize;

                // ... then add this ellipse to the canvas as a visual element
                this.canvas.Children.Add(ellipse);

                // ... and set the position (left/top).
                ellipse.SetValue(Canvas.LeftProperty, (double)(tp.Position.X - drawingSize / 2.0));
                ellipse.SetValue(Canvas.TopProperty, (double)(tp.Position.Y - drawingSize / 2.0));

                // Then create a new animation for double values, and 
                // set the target "To" property to be the bottom of the screen.
                DoubleAnimation animation = new DoubleAnimation();
                animation.To = this.canvas.ActualHeight - drawingSize;

                // Next, we add a bouncing easing function; with random values
                // for number of bounces and bounciness
                BounceEase bounce = new BounceEase();
                bounce.Bounces = this.random.Next(6) + 3;
                bounce.Bounciness = this.random.Next(8) + 2;
                animation.EasingFunction = bounce;

                // Last, we create a storyboard, set the target of the animation to be
                // the ellipse, set the property to TopProperty location, and 
                // start the storyboard
                Storyboard storyboard = new Storyboard();
                Storyboard.SetTarget(animation, ellipse);
                Storyboard.SetTargetProperty(animation, new PropertyPath(Canvas.TopProperty)); 
                storyboard.Children.Add(animation);
                storyboard.Begin();
            }
        }


        // Get a random color
        private Color GetRandomColour()
        {
            return Color.FromArgb(
                (byte)255,
                (byte)this.random.Next(255),
                (byte)this.random.Next(255),
                (byte)this.random.Next(255));
        }

        // Get a random color
        private Color GetRandomFadingColour()
        {
            r = (r + this.random.Next(10)) % 255;
            g = (g + this.random.Next(15)) % 255;
            b = (b + this.random.Next(30)) % 255;
            return Color.FromArgb((byte)255, (byte)r, (byte)g, (byte)b);
        }

    }
}